@@ -59,16 +59,17 @@ LONG VIEW OPTIONS
   -H, --links                list each file's number of hard links
   -i, --inode                list each file's inode number
   -m, --modified             use the modified timestamp field
-  -M, --mounts               show mount details (Linux and MacOS only)
+  -M, --mounts               show mount details (Linux and Mac only)
   -n, --numeric              list numeric user and group IDs
+  -O, --flags                list file flags (Mac, BSD, and Windows only)
   -S, --blocksize            show size of allocated file system blocks
   -t, --time FIELD           which timestamp field to list (modified, accessed, created)
   -u, --accessed             use the accessed timestamp field
   -U, --created              use the created timestamp field
   --changed                  use the changed timestamp field
   --time-style               how to format timestamps (default, iso, long-iso,
-                             full-iso, relative, or a custom style with '+' as
-                             prefix. Ex: '+%Y/%m/%d')
+                             full-iso, relative, or a custom style '+<FORMAT>'
+                             like '+%Y-%m-%d %H:%M')
   --total-size               show the size of a directory as the size of all
                              files and directories inside (unix only)
   --no-permissions           suppress the permissions field
